# $Id$

package MultiPackage;

use vars qw($VERSION);

$VERSION = '0.03';

package SubPackageOne;

use vars qw($VERSION);

$VERSION = '0.02';

package SubPackageTwo;

use vars qw($VERSION);

$VERSION = 0.01;

1;

__END__